# IP Fabric < Human Readable Project Name >

## IP Fabric

IP Fabric is a vendor-neutral network assurance platform that automates the 
holistic discovery, verification, visualization, and documentation of 
large-scale enterprise networks, reducing the associated costs and required 
resources whilst improving security and efficiency.

It supports your engineering and operations teams, underpinning migration and 
transformation projects. IP Fabric will revolutionize how you approach network 
visibility and assurance, security assurance, automation, multi-cloud 
networking, and trouble resolution.

## Project Description

< Summary of the Project >

## Installation

< Installation Information >

## Configuration

< Configuration Information >

## Usage

< Any external documentation to reference? If not remove section >

## Support

TODO: How to open issue in Gitlab, some base information around it, etc.

## Contributing

TODO: How to contribute?
